clone

package
v0.0.0-...-ae5e3d9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CloneFromGitgres

func CloneFromGitgres(ctx context.Context, conninfo, reponame string) (dir string, cleanup func(), err error)

CloneFromGitgres clones the repository named reponame from Postgres (conninfo) into a temp dir and returns that dir and a cleanup function. The worktree is checked out so the directory contains files for scanning.

func FetchAndPushToGitgres

func FetchAndPushToGitgres(ctx context.Context, conninfo, reponame, gitURL string) (cleanup func(), err error)

FetchAndPushToGitgres clones gitURL into a temp dir, pushes that repo to Postgres under the given conninfo and reponame, then returns a cleanup function. The repo is created in Postgres if it does not exist.

Types

This section is empty.

Jump to